import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';

class AvatarCurve extends CustomClipper<Path> {
  AvatarCurve({this.avatarSize, this.percentage});
  Size avatarSize;
  double percentage;

  @override
  Path getClip(Size size) {
    final double avatarRadius = avatarSize.width / 2 - 2 * (1 - percentage);
    final double backgroundHeight =
        140 * (1 - percentage) < 43 ? 43 : 140 * (1 - percentage);

    final Offset circleCenter = Offset(
      size.width / 2,
      backgroundHeight,
    );

    const Offset topLeft = Offset(0, 0);
    final Offset bottomLeft = Offset(0, backgroundHeight);

    final Offset topRight = Offset(size.width, 0);
    final Offset bottomRight = Offset(size.width, backgroundHeight);

    final double headerLeftTurningPointX = circleCenter.dx - avatarRadius;
    final double headerLeftTurningPointY = backgroundHeight;

    final double headerRightTurningPointX = circleCenter.dx + avatarRadius;
    final double headerRightTurningPointY = backgroundHeight;

    final Offset headerLeftTurningPoint = Offset(
      headerLeftTurningPointX,
      headerLeftTurningPointY,
    );

    final Offset headerRightTurningPoint = Offset(
      headerRightTurningPointX,
      headerRightTurningPointY,
    );

    final Path path = Path();
    path.lineTo(topLeft.dx, topLeft.dy);
    path.lineTo(bottomLeft.dx, bottomLeft.dy);
    path.lineTo(
      circleCenter.dx - avatarSize.width * 0.7,
      headerLeftTurningPoint.dy,
    );

    path.cubicTo(
      circleCenter.dx - avatarRadius * 0.95,
      backgroundHeight,
      circleCenter.dx - avatarSize.width * 0.5,
      circleCenter.dy - avatarSize.width * 0.47,
      circleCenter.dx,
      circleCenter.dy - avatarRadius,
    );

    path.cubicTo(
      circleCenter.dx + avatarSize.width * 0.5,
      circleCenter.dy - avatarSize.width * 0.47,
      circleCenter.dx + avatarRadius * 0.95,
      backgroundHeight,
      circleCenter.dx + avatarSize.width * 0.7,
      backgroundHeight,
    );

    path.lineTo(circleCenter.dx + avatarSize.width, headerRightTurningPoint.dy);
    path.lineTo(bottomRight.dx, bottomRight.dy);
    path.lineTo(topRight.dx, topRight.dy);

    path.close();
    return path;
  }

  @override
  bool shouldReclip(CustomClipper<Path> oldClipper) => false;
}
